==> metabar-0.6.tar.gz: metabar/src/metaframe.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Florian Roth   *
 *   florian@synatic.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#ifndef _METAFRAME_H_
#define _METAFRAME_H_

#include <qframe.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qevent.h>
#include <qtimer.h>
#include <kpushbutton.h>

#ifdef HAVE_XRENDER
#  include <X11/Xlib.h>
#  include <X11/extensions/Xrender.h>
#endif

class FadeWidget : public QWidget
{
  Q_OBJECT
  
  public:
    FadeWidget(QWidget *parent = 0, const char *name = 0);
    ~FadeWidget();
    
  public slots:
    void fadeIn();
    void fadeIn(bool);
    void fadeOut();
    
  protected:
    void paintEvent(QPaintEvent *e);
    
  private:
    QTimer *timer;
};

class TitleLabel : public QLabel
{
  Q_OBJECT
  
  public:
    TitleLabel(QWidget *parent = 0, const char *name = 0);
    ~TitleLabel();
    
    const bool toggled();
    void setToggled(const bool b);
    
  protected:
    void paintEvent(QPaintEvent *e);
    void mouseReleaseEvent(QMouseEvent *e);
    
  private:
    bool isToggled;
    
  signals:
    void toggled(bool);
};

class MetaFrame : public QFrame
{
  Q_OBJECT
  
  public:
    MetaFrame(QWidget *parent = 0, const char *name = 0);
    ~MetaFrame();
    
    void addWidget(QWidget *widget, bool adjust = true);
    
    const QString title();
    bool isExpanded();
    QWidget* mainWidget();
  
  public slots:
    void setTitle(const QString &title);
    void setExpanded(bool b = true);
    void collapse(bool b);
    void animateResize();
  
  private:
    FadeWidget *main;
    QVBoxLayout *layout;
    
    TitleLabel *titleLabel;
    
    QTimer *timer;
    int wishedHeight;
    
  private slots:
    void animateResizeImpl();
    
  signals:
    void toggled(bool);
};

#endif

==> metabar_0.7.orig.tar.gz: metabar/src/metaframe.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Florian Roth   *
 *   florian@synatic.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#ifndef _METAFRAME_H_
#define _METAFRAME_H_

#include <qframe.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qevent.h>
#include <qtimer.h>
#include <kpushbutton.h>
#include <kconfig.h>


class FadeLine : public QWidget
{
  Q_OBJECT
  
  public:
    FadeLine(QWidget *parent = 0, const char *name = 0, int height = 2);
    ~FadeLine();
    
  protected:
    void paintEvent(QPaintEvent *e);
};

class MetaFrame : public QFrame
{
  Q_OBJECT
  
  public:
    MetaFrame(KConfig *config, QWidget *parent = 0, const char *name = 0);
    ~MetaFrame();
    
    void addWidget(QWidget *widget, bool adjust = true);
    
    const QString title();
    bool isExpanded();
    QWidget* mainWidget();
  
  public slots:
    void setTitle(const QString &title);
    void setExpanded(bool b = true);
    void collapse(bool b);
    void animateResize();
    void resize();
  
  private:
    QWidget *main;
    QVBoxLayout *layout;
    
    KPushButton *titleButton;
    
    KConfig *config;
    
    QTimer *timer;
    int wishedHeight;
    
  private slots:
    void animateResizeImpl();
    
  signals:
    void toggled(bool);
};

#endif
